@@ -5,6 +5,7 @@ import requests_cache
 from afacinemas_scraper.core.cinemas import ScraperCinemas
 from afacinemas_scraper.core.lancamentos import ScraperLancamentos
 from afacinemas_scraper.core.precos import ScraperPrecos
+from afacinemas_scraper.core.programacao import ScraperProgramacao
 
 requests_cache.install_cache(
     "cache_afacinemas", backend="sqlite", expire_after=600
@@ -24,9 +25,12 @@ class Scraper:
         sc = ScraperPrecos()
         return sc.extract(codigo)
 
+    def get_programacao(self, codigo: int, data: str):
+        sc = ScraperProgramacao()
+        return sc.extract(codigo, data)
+
 
 if __name__ == "__main__":
     afa = Scraper()
-    cinemas = afa.get_cinemas()
-    proximos_lancamentos = afa.get_proximos_lancamentos()
-    print(afa.get_precos_ingressos(codigo=10))
+    programacao = afa.get_programacao(10, "2022-06-30")
+    print(programacao)
